@@ -5,8 +5,10 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "multidatachecker.h"
+
+#include <KLocalizedString>
+
 #include <diskio/dndfile.h>
-#include <klocalizedstring.h>
 #include <torrent/globals.h>
 #include <torrent/torrent.h>
 #include <torrent/torrentfile.h>
@@ -17,6 +19,8 @@
 #include <util/functions.h>
 #include <util/log.h>
 
+using namespace Qt::Literals::StringLiterals;
+
 namespace bt
 {
 MultiDataChecker::MultiDataChecker(bt::Uint32 from, bt::Uint32 to)
@@ -132,10 +136,10 @@ bool MultiDataChecker::loadChunk(Uint32 ci, Uint32 cs, const Torrent &tor)
 
         // read part of data
         if (f.doNotDownload()) {
-            QString dnd_path = QString("file%1.dnd").arg(f.getIndex());
+            QString dnd_path = u"file%1.dnd"_s.arg(f.getIndex());
             QString dnd_file = dnd_dir + dnd_path;
             if (!bt::Exists(dnd_file)) // could be an old style dnd dir
-                dnd_file = dnd_dir + f.getUserModifiedPath() + ".dnd";
+                dnd_file = dnd_dir + f.getUserModifiedPath() + ".dnd"_L1;
 
             if (bt::Exists(dnd_file)) {
                 Uint32 ret = 0;
@@ -177,7 +181,7 @@ File::Ptr MultiDataChecker::open(const bt::Torrent &tor, Uint32 idx)
 
     const TorrentFile &tf = tor.getFile(idx);
     File::Ptr fptr(new File());
-    if (!fptr->open(tf.getPathOnDisk(), "rb")) {
+    if (!fptr->open(tf.getPathOnDisk(), u"rb"_s)) {
         QString err = i18n("Cannot open file %1: %2", tf.getPathOnDisk(), fptr->errorString());
         Out(SYS_GEN | LOG_DEBUG) << err << endl;
         throw Error(err);
