@@ -2,7 +2,7 @@
 #define QT_GUI_LIB
 #endif
 
-#include <time.h>
+#include <ctime>
 
 #include <QEventLoop>
 #include <QLocale>
@@ -18,9 +18,8 @@
 #include <util/functions.h>
 #include <util/log.h>
 
-#include <boost/concept_check.hpp>
-
 using namespace bt;
+using namespace Qt::Literals::StringLiterals;
 
 const bt::Uint64 TEST_FILE_SIZE = 15 * 1024 * 1024;
 
@@ -38,9 +37,9 @@ public:
 private Q_SLOTS:
     void initTestCase()
     {
-        QLocale::setDefault(QLocale("main"));
+        QLocale::setDefault(QLocale(u"main"_s));
         bt::InitLibKTorrent();
-        bt::InitLog("datacheckertest.log", false, true);
+        bt::InitLog(u"datacheckertest.log"_s, false, true);
     }
 
     void testSingleFile()
@@ -48,11 +47,11 @@ private Q_SLOTS:
         Out(SYS_GEN | LOG_DEBUG) << "testSingleFile" << endl;
         DummyTorrentCreator creator;
         bt::TorrentControl tc;
-        QVERIFY(creator.createSingleFileTorrent(TEST_FILE_SIZE, "test.avi"));
+        QVERIFY(creator.createSingleFileTorrent(TEST_FILE_SIZE, u"test.avi"_s));
 
         Out(SYS_GEN | LOG_DEBUG) << "Created " << creator.torrentPath() << endl;
         try {
-            tc.init(nullptr, bt::LoadFile(creator.torrentPath()), creator.tempPath() + "tor0", creator.tempPath() + "data/");
+            tc.init(nullptr, bt::LoadFile(creator.torrentPath()), creator.tempPath() + "tor0"_L1, creator.tempPath() + "data/"_L1);
             tc.createFiles();
         } catch (bt::Error &err) {
             Out(SYS_GEN | LOG_DEBUG) << "Failed to load torrent: " << creator.torrentPath() << endl;
@@ -61,7 +60,7 @@ private Q_SLOTS:
 
         SingleDataChecker dc(0, tc.getStats().total_chunks);
         try {
-            QString dnd = tc.getTorDir() + "dnd" + bt::DirSeparator();
+            QString dnd = tc.getTorDir() + "dnd"_L1 + bt::DirSeparator();
             dc.check(tc.getStats().output_path, tc.getTorrent(), dnd, tc.downloadedChunksBitSet());
             QVERIFY(dc.getResult().allOn());
         } catch (bt::Error &err) {
@@ -75,17 +74,17 @@ private Q_SLOTS:
         Out(SYS_GEN | LOG_DEBUG) << "testMultiFile" << endl;
         QMap<QString, bt::Uint64> files;
 
-        files["aaa.avi"] = RandomSize(TEST_FILE_SIZE / 2, TEST_FILE_SIZE);
-        files["bbb.avi"] = RandomSize(TEST_FILE_SIZE / 2, TEST_FILE_SIZE);
-        files["ccc.avi"] = RandomSize(TEST_FILE_SIZE / 2, TEST_FILE_SIZE);
+        files[u"aaa.avi"_s] = RandomSize(TEST_FILE_SIZE / 2, TEST_FILE_SIZE);
+        files[u"bbb.avi"_s] = RandomSize(TEST_FILE_SIZE / 2, TEST_FILE_SIZE);
+        files[u"ccc.avi"_s] = RandomSize(TEST_FILE_SIZE / 2, TEST_FILE_SIZE);
 
         DummyTorrentCreator creator;
         bt::TorrentControl tc;
-        QVERIFY(creator.createMultiFileTorrent(files, "movies"));
+        QVERIFY(creator.createMultiFileTorrent(files, u"movies"_s));
 
         Out(SYS_GEN | LOG_DEBUG) << "Created " << creator.torrentPath() << endl;
         try {
-            tc.init(nullptr, bt::LoadFile(creator.torrentPath()), creator.tempPath() + "tor0", creator.tempPath() + "data/");
+            tc.init(nullptr, bt::LoadFile(creator.torrentPath()), creator.tempPath() + "tor0"_L1, creator.tempPath() + "data/"_L1);
             tc.createFiles();
         } catch (bt::Error &err) {
             Out(SYS_GEN | LOG_DEBUG) << "Failed to load torrent: " << creator.torrentPath() << endl;
@@ -94,7 +93,7 @@ private Q_SLOTS:
 
         MultiDataChecker dc(0, tc.getStats().total_chunks);
         try {
-            QString dnd = tc.getTorDir() + "dnd" + bt::DirSeparator();
+            QString dnd = tc.getTorDir() + "dnd"_L1 + bt::DirSeparator();
             dc.check(tc.getStats().output_path, tc.getTorrent(), dnd, tc.downloadedChunksBitSet());
             QVERIFY(dc.getResult().allOn());
         } catch (bt::Error &err) {
@@ -107,18 +106,18 @@ private Q_SLOTS:
     {
         QMap<QString, bt::Uint64> files;
 
-        files["aaa.avi"] = RandomSize(TEST_FILE_SIZE / 2, TEST_FILE_SIZE);
-        files["bbb.avi"] = RandomSize(TEST_FILE_SIZE / 2, TEST_FILE_SIZE);
-        files["ccc.avi"] = RandomSize(TEST_FILE_SIZE / 2, TEST_FILE_SIZE);
-        files["ddd.avi"] = RandomSize(TEST_FILE_SIZE / 2, TEST_FILE_SIZE);
+        files[u"aaa.avi"_s] = RandomSize(TEST_FILE_SIZE / 2, TEST_FILE_SIZE);
+        files[u"bbb.avi"_s] = RandomSize(TEST_FILE_SIZE / 2, TEST_FILE_SIZE);
+        files[u"ccc.avi"_s] = RandomSize(TEST_FILE_SIZE / 2, TEST_FILE_SIZE);
+        files[u"ddd.avi"_s] = RandomSize(TEST_FILE_SIZE / 2, TEST_FILE_SIZE);
 
         DummyTorrentCreator creator;
         bt::TorrentControl tc;
-        QVERIFY(creator.createMultiFileTorrent(files, "movies"));
+        QVERIFY(creator.createMultiFileTorrent(files, u"movies"_s));
 
         Out(SYS_GEN | LOG_DEBUG) << "Created " << creator.torrentPath() << endl;
         try {
-            tc.init(nullptr, bt::LoadFile(creator.torrentPath()), creator.tempPath() + "tor0", creator.tempPath() + "data/");
+            tc.init(nullptr, bt::LoadFile(creator.torrentPath()), creator.tempPath() + "tor0"_L1, creator.tempPath() + "data/"_L1);
             tc.createFiles();
         } catch (bt::Error &err) {
             Out(SYS_GEN | LOG_DEBUG) << "Failed to load torrent: " << creator.torrentPath() << endl;
@@ -129,7 +128,7 @@ private Q_SLOTS:
             const bt::TorrentFileInterface &fi = tc.getTorrentFile(file);
             MultiDataChecker dc(fi.getFirstChunk(), fi.getLastChunk());
             try {
-                QString dnd = tc.getTorDir() + "dnd" + bt::DirSeparator();
+                QString dnd = tc.getTorDir() + "dnd"_L1 + bt::DirSeparator();
                 dc.check(tc.getStats().output_path, tc.getTorrent(), dnd, tc.downloadedChunksBitSet());
                 for (Uint32 i = 0; i < tc.getStats().total_chunks; i++)
                     QVERIFY(dc.getResult().get(i) == (i >= fi.getFirstChunk() && i <= fi.getLastChunk()));
