@@ -26,6 +26,8 @@
 #include <util/log.h>
 #include <util/waitjob.h>
 
+using namespace Qt::Literals::StringLiterals;
+
 namespace bt
 {
 bool HTTPTracker::proxy_on = false;
@@ -105,7 +107,7 @@ void HTTPTracker::scrape()
     QString epq = scrape_url.query(QUrl::FullyEncoded);
     const SHA1Hash &info_hash = tds->infoHash();
     if (epq.length())
-        epq += '&';
+        epq += '&'_L1;
     epq += QLatin1String("info_hash=") + info_hash.toURLString();
     scrape_url.setQuery(epq, QUrl::StrictMode);
 
@@ -351,8 +353,7 @@ void HTTPTracker::onAnnounceResult(const QUrl &url, const QByteArray &data, KJob
 {
     timer.stop();
     active_job = nullptr;
-    KIOAnnounceJob *st = (KIOAnnounceJob *)j;
-    if (st->IsErrorPage() || (j->error() && data.size() == 0)) {
+    if (j->error() && data.size() == 0) {
         QString err = error;
         error.clear();
         if (err.isEmpty())
@@ -360,10 +361,6 @@ void HTTPTracker::onAnnounceResult(const QUrl &url, const QByteArray &data, KJob
 
         Out(SYS_TRK | LOG_IMPORTANT) << "Error : " << err << endl;
 
-        if (st->IsErrorPage()) {
-            Out(SYS_TRK | LOG_IMPORTANT) << "HTTP Error page : " << QString::fromStdString(st->replyData().toStdString()) << endl;
-        }
-
         if (QUrlQuery(url).queryItemValue(QStringLiteral("event")) != QLatin1String("stopped")) {
             failures++;
             failed(err);
@@ -407,26 +404,26 @@ void HTTPTracker::emitInvalidURLFailure()
 
 void HTTPTracker::setupMetaData(KIO::MetaData &md)
 {
-    md["UserAgent"] = bt::GetVersionString();
-    md["SendLanguageSettings"] = "false";
-    md["cookies"] = "none";
-    //  md["accept"] = "text/plain";
-    md["accept"] = "text/html, image/gif, image/jpeg, *; q=.2, */*; q=.2";
+    md[u"UserAgent"_s] = bt::GetVersionString();
+    md[u"SendLanguageSettings"_s] = u"false"_s;
+    md[u"cookies"_s] = u"none"_s;
+    //  md[u"accept"_s] = u"text/plain"_s;
+    md[u"accept"_s] = u"text/html, image/gif, image/jpeg, *; q=.2, */*; q=.2"_s;
     if (proxy_on) {
-        QString p = QString("%1:%2").arg(proxy).arg(proxy_port);
+        QString p = u"%1:%2"_s.arg(proxy).arg(proxy_port);
         if (!p.startsWith(QLatin1String("http://")))
-            p = "http://" + p;
+            p = "http://"_L1 + p;
         // set the proxy if the doNotUseKDEProxy ix enabled (URL must be valid to)
         QUrl url(p);
         if (url.isValid() && proxy.trimmed().length() > 0) {
-            md["UseProxy"] = p;
-            md["ProxyUrls"] = p;
+            md[u"UseProxy"_s] = p;
+            md[u"ProxyUrls"_s] = p;
         } else {
-            md["UseProxy"] = QString();
-            md["ProxyUrls"] = QString();
+            md[u"UseProxy"_s] = QString();
+            md[u"ProxyUrls"_s] = QString();
         }
 
-        Out(SYS_TRK | LOG_DEBUG) << "Using proxy : " << md["UseProxy"] << endl;
+        Out(SYS_TRK | LOG_DEBUG) << "Using proxy : " << md[u"UseProxy"_s] << endl;
     }
 }
 
